@@ -1,10 +1,14 @@
-import logging
 import json
+import logging
+import os
+
+from frinx_conductor_workers.frinx_rest import conductor_headers
+from frinx_conductor_workers.frinx_rest import resource_manager_url_base
+from frinx_conductor_workers.logging_helpers import logging_handler
+from frinx_conductor_workers.util import completed_response_with_logs
+from frinx_conductor_workers.util import failed_response_with_logs
 from jinja2 import Template
 from python_graphql_client import GraphqlClient
-from logging_helpers import logging_handler
-from util import completed_response, failed_response
-from frinx_conductor_workers.frinx_rest import conductor_headers, resource_manager_url_base
 
 log = logging.getLogger(__name__)
 
@@ -20,6 +24,7 @@ claim_resource_template = Template(
     {
         id
         Properties
+        AlternativeId
     }
     }"""
 )
@@ -77,6 +82,7 @@ query_pool_by_tag_template = Template(
     SearchPoolsByTags(tags: { matchesAny: [{matchesAll: [$poolTag]}]}) {
         id
         Name
+        PoolProperties
     }
     } """
 )
@@ -92,6 +98,7 @@ query_claimed_resource_template = Template(
             node {
                 id
                 Properties
+                AlternativeId
                 }
             }
         }
@@ -136,6 +143,9 @@ def claim_resource(task, logs):
                   "Properties": {
                     <properties>
                   }
+                  "AlternativeId": {
+                    <alternativeId>
+                  }
                 }
               }
             }
@@ -143,27 +153,17 @@ def claim_resource(task, logs):
     """
     pool_id = task["inputData"]["poolId"] if "poolId" in task["inputData"] else None
     if pool_id is None:
-        return failed_response("No pool id")
-    user_input = (
-        task["inputData"]["userInput"] if "userInput" in task["inputData"] else {}
-    )
-    description = (
-        task["inputData"]["description"] if "description" in task["inputData"] else ""
-    )
+        return failed_response_with_logs(logs, "No pool id")
+    user_input = task["inputData"]["userInput"] if "userInput" in task["inputData"] else {}
+    description = task["inputData"]["description"] if "description" in task["inputData"] else ""
     alternative_id = (
-        None
-        if "alternativeId" not in task["inputData"]
-        else task["inputData"]["alternativeId"]
+        None if "alternativeId" not in task["inputData"] else task["inputData"]["alternativeId"]
     )
-    variables = {
-        "pool_id": pool_id,
-        "user_input": user_input,
-        "description": description,
-    }
+    variables = {"pool_id": pool_id, "user_input": user_input, "description": description}
 
-    if len(task["inputData"]["alternativeId"]) > 1 and alternative_id is not None:
-        alternative_id = alternative_id.replace("'", "\"")
-        alternative_id = json.loads(alternative_id)
+    if alternative_id is not None and len(alternative_id) > 0:
+        if "status" not in alternative_id:
+            alternative_id.update({"status": "active"})
         variables.update({"alternative_id": alternative_id})
         body = claim_resource_template.render(
             {
@@ -174,20 +174,14 @@ def claim_resource(task, logs):
         )
     else:
         body = claim_resource_template.render(
-            {
-                "claim_resource": "ClaimResource",
-                "alternative_id_variable": "",
-                "alternative_id": "",
-            }
+            {"claim_resource": "ClaimResource", "alternative_id_variable": "", "alternative_id": ""}
         )
 
-
     log.debug("Sending graphql variables: %s\n with query: %s" % (variables, body))
     response = execute(body, variables)
     if "errors" in response:
-        return failed_response({"response_body": response["errors"][0]["message"]})
-    return completed_response({"response_body": response["data"]})
-
+        return failed_response_with_logs(logs, {"response_body": response["errors"][0]["message"]})
+    return completed_response_with_logs(logs, {"response_body": response["data"]})
 
 
 @logging_handler(log)
@@ -214,6 +208,9 @@ def query_claimed_resources(task, logs):
                           "Properties": {
                             <properties>
                           }
+                          "AlternativeId": {
+                            <alternativeId>
+                          }
                         }
                     }
                 }
@@ -223,14 +220,15 @@ def query_claimed_resources(task, logs):
     """
     pool_id = task["inputData"]["poolId"] if "poolId" in task["inputData"] else None
     alternative_id = (
-        None
-        if "alternativeId" not in task["inputData"]
-        else task["inputData"]["alternativeId"]
+        None if "alternativeId" not in task["inputData"] else task["inputData"]["alternativeId"]
     )
     if pool_id is None:
-        return failed_response(logs, "No pool id")
+        return failed_response_with_logs(logs, "No pool id")
     variables = {"pool_id": pool_id}
-    if alternative_id is not None:
+    if alternative_id is not None and len(alternative_id) > 0:
+        alternative_id = alternative_id.replace("'", '"')
+        alternative_id = json.loads(alternative_id)
+        variables.update({"alternative_id": alternative_id})
         body = query_claimed_resource_template.render(
             {
                 "query_resource": "QueryResourcesByAltId",
@@ -240,25 +238,21 @@ def query_claimed_resources(task, logs):
         )
         variables.update({"input": alternative_id})
     else:
-        body = query_claimed_resource_template.render(
-            {"query_resource": "QueryResources"}
-        )
+        body = query_claimed_resource_template.render({"query_resource": "QueryResources"})
     log.debug("Sending graphql variables: %s\n with query: %s" % (variables, body))
     data = execute(body, variables)
-    return completed_response({"response_body": data})
+    return completed_response_with_logs(logs, {"response_body": data})
 
 
 def query_resource_id(resource):
     # Query resource type and resource allocation strategy id from uniresource
     body = query_resource_template.render()
     variables = {"resource": resource}
-    body = body.replace('\n', '').replace('\\', '')
+    body = body.replace("\n", "").replace("\\", "")
     log.debug("Sending graphql variables: %s\n with query: %s" % (variables, body))
     data = execute(body, variables)
     resource_type_id = (
-        data["data"]["QueryResourceTypes"][0]["id"]
-        if data["data"]["QueryResourceTypes"]
-        else None
+        data["data"]["QueryResourceTypes"][0]["id"] if data["data"]["QueryResourceTypes"] else None
     )
     resource_strategy_id = (
         data["data"]["QueryAllocationStrategies"][0]["id"]
@@ -294,11 +288,11 @@ def create_pool(task, logs):
     """
 
     pool_name = task["inputData"]["poolName"]
-    resource = task["inputData"]["resource"]
-    resource_type_id, resource_strategy_id = query_resource_id(resource)
+    resource_type = task["inputData"]["resourceType"]
+    resource_type_id, resource_strategy_id = query_resource_id(resource_type)
     if resource_type_id is None or resource_strategy_id is None:
-        log.warning("Unknown resource: %s", resource)
-        return failed_response(logs, "Unknown resource")
+        log.warning("Unknown resource: %s", resource_type)
+        return failed_response_with_logs(logs, "Unknown resource")
 
     variables = {
         "resource_type_id": resource_type_id,
@@ -333,20 +327,20 @@ def create_pool(task, logs):
             variables.update({key: pool_properties[key]})
 
     body = create_pool_template.render(
-    {
-        "create_pool": "CreateAllocatingPool",
-        "pool_properties_types": "poolPropertyTypes: {\n" + pool_types_string + "\n}",
-        "pool_properties": "poolProperties: {\n" + pool_string + "\n}",
-        "pool_properties_variables": pool_variables_string,
-    }
+        {
+            "create_pool": "CreateAllocatingPool",
+            "pool_properties_types": "poolPropertyTypes: {\n" + pool_types_string + "\n}",
+            "pool_properties": "poolProperties: {\n" + pool_string + "\n}",
+            "pool_properties_variables": pool_variables_string,
+        }
     )
-    body = body.replace('\n', '').replace('\\', '')
-    
+    body = body.replace("\n", "").replace("\\", "")
+
     log.debug("Sending graphql variables: %s\n with query: %s" % (variables, body))
     response = execute(body, variables)
     if "errors" in response:
-        return failed_response({"response_body": response["errors"][0]["message"]})
-    return completed_response({"response_body": response["data"]})
+        return failed_response_with_logs(logs, {"response_body": response["errors"][0]["message"]})
+    return completed_response_with_logs(logs, {"response_body": response["data"]})
 
 
 @logging_handler(log)
@@ -363,9 +357,7 @@ def create_vlan_pool(task, logs):
     from_range = task["inputData"]["from"] if "from" in task["inputData"] else None
     to_range = task["inputData"]["to"] if "to" in task["inputData"] else None
     parent_resource_id = (
-        task["inputData"]["parentResourceId"]
-        if "parentResourceId" in task["inputData"]
-        else None
+        task["inputData"]["parentResourceId"] if "parentResourceId" in task["inputData"] else None
     )
     if parent_resource_id == "":
         parent_resource_id = None
@@ -383,9 +375,7 @@ def create_vlan_pool(task, logs):
         body = create_pool_template.render(
             {
                 "create_pool": "CreateNestedAllocatingPool",
-                "parent_resource_id": 'parentResourceId: "'
-                + str(parent_resource_id)
-                + '"',
+                "parent_resource_id": 'parentResourceId: "' + str(parent_resource_id) + '"',
             }
         )
     else:
@@ -399,7 +389,7 @@ def create_vlan_pool(task, logs):
         )
     log.debug("Sending graphql variables: %s\n with query: %s" % (variables, body))
     data = execute(body, variables)
-    return completed_response({"response_body": data})
+    return completed_response_with_logs(logs, {"response_body": data})
 
 
 @logging_handler(log)
@@ -435,7 +425,7 @@ def create_vlan_range_pool(task, logs):
     )
     log.debug("Sending graphql variables: %s\n with query: %s" % (variables, body))
     data = execute(body, variables)
-    return completed_response({"response_body": data})
+    return completed_response_with_logs(logs, {"response_body": data})
 
 
 @logging_handler(log)
@@ -488,7 +478,7 @@ def create_unique_id_pool(task, logs):
     )
     log.debug("Sending graphql variables: %s\n with query: %s" % (variables, body))
     data = execute(body, variables)
-    return completed_response({"response_body": data})
+    return completed_response_with_logs(logs, {"response_body": data})
 
 
 @logging_handler(log)
@@ -522,7 +512,7 @@ def query_pool(task, logs):
     resource_type_id, resource_strategy_id = query_resource_id(resource)
     if resource_type_id is None or resource_strategy_id is None:
         log.warning("Unknown resource: %s", resource)
-        return failed_response(logs, "Unknown resource")
+        return failed_response_with_logs(logs, "Unknown resource")
     pool_names_string = ""
     for index, pool_name in enumerate(pool_names):
         pool_names_string += '"' + pool_name + '"'
@@ -532,7 +522,7 @@ def query_pool(task, logs):
     body = query_pool_template.render({"pool_names": pool_names_string})
     log.debug("Sending graphql variables: %s\n with query: %s" % (variables, body))
     data = execute(body, variables)
-    return completed_response({"response_body": data})
+    return completed_response_with_logs(logs, {"response_body": data})
 
 
 @logging_handler(log)
@@ -551,8 +541,8 @@ def query_unique_id_pool(task, logs):
     query_pool_result = query_pool(
         {"inputData": {"resource": "unique_id", "poolNames": pool_names}}
     )
-    return completed_response(
-        {"response_body": query_pool_result["output"]["response_body"]}
+    return completed_response_with_logs(
+        logs, {"response_body": query_pool_result["output"]["response_body"]}
     )
 
 
@@ -569,13 +559,12 @@ def query_vlan_pool(task, logs):
 
     """
     pool_names = task["inputData"]["poolNames"]
-    query_pool_result = query_pool(
-        {"inputData": {"resource": "vlan", "poolNames": pool_names}}
-    )
-    return completed_response(
-        {"response_body": query_pool_result["output"]["response_body"]}
+    query_pool_result = query_pool({"inputData": {"resource": "vlan", "poolNames": pool_names}})
+    return completed_response_with_logs(
+        logs, {"response_body": query_pool_result["output"]["response_body"]}
     )
 
+
 @logging_handler(log)
 def query_pool_by_tag(task, logs):
     """
@@ -597,18 +586,17 @@ def query_pool_by_tag(task, logs):
                         }
                     ]
                 }
-            } 
-    
+            }
+
     """
     pool_tag = task["inputData"]["poolTag"]
     body = query_pool_by_tag_template.render()
     variables = {"poolTag": pool_tag}
-    body = body.replace('\n', '').replace('\\', '')
+    body = body.replace("\n", "").replace("\\", "")
     log.debug("Sending graphql variables: %s\n with query: %s" % (variables, body))
     response_data = execute(body, variables)
-    return completed_response(
-        {"response_body": response_data}
-    )
+    return completed_response_with_logs(logs, {"response_body": response_data})
+
 
 @logging_handler(log)
 def query_vlan_range_pool(task, logs):
@@ -626,8 +614,8 @@ def query_vlan_range_pool(task, logs):
     query_pool_result = query_pool(
         {"inputData": {"resource": "vlan_range", "poolNames": pool_names}}
     )
-    return completed_response(
-        {"response_body": query_pool_result["output"]["response_body"]}
+    return completed_response_with_logs(
+        logs, {"response_body": query_pool_result["output"]["response_body"]}
     )
 
 
@@ -638,7 +626,7 @@ def update_alt_id_for_resource(task, logs):
 
          Args:
 
-             task (dict): dictionary with input data ["poolId", "userInput", "alternativeId"]
+             task (dict): dictionary with input data ["poolId", "resourceProperties", "alternativeId"]
 
              logs: stream of log messages
 
@@ -657,30 +645,128 @@ def update_alt_id_for_resource(task, logs):
     """
     pool_id = task["inputData"]["poolId"] if "poolId" in task["inputData"] else None
     if pool_id is None:
-        return failed_response(logs, "No pool id")
-    user_input = (
-        task["inputData"]["userInput"] if "userInput" in task["inputData"] else None
-    )
-    if user_input is None:
-        return failed_response(logs, "No user input")
-    alternative_id = (
-        task["inputData"]["alternativeId"]
-        if "alternativeId" in task["inputData"]
+        return failed_response_with_logs(logs, "No pool id")
+    resource_properties = (
+        task["inputData"]["resourceProperties"]
+        if "resourceProperties" in task["inputData"]
         else None
     )
+    if resource_properties is None:
+        return failed_response_with_logs(logs, "No user input")
+    alternative_id = (
+        task["inputData"]["alternativeId"] if "alternativeId" in task["inputData"] else None
+    )
     if alternative_id is None:
-        return failed_response(logs, "No alternative id")
-    variables = {
-        "pool_id": pool_id,
-        "input": user_input,
-        "alternative_id": alternative_id,
-    }
+        return failed_response_with_logs(logs, "No alternative id")
+    variables = {"pool_id": pool_id, "input": resource_properties, "alternative_id": alternative_id}
+    if alternative_id is not None and len(alternative_id) > 0:
+        alternative_id = alternative_id.replace("'", '"')
+        alternative_id = json.loads(alternative_id)
+        variables.update({"alternative_id": alternative_id})
+    if resource_properties is not None and len(resource_properties) > 0:
+        variables.update({"input": resource_properties})
     body = update_alternative_id_for_resource_template.render(
         {"update_alt_id": "UpdateResourceAltId"}
     )
     log.debug("Sending graphql variables: %s\n with query: %s" % (variables, body))
     data = execute(body, variables)
-    return completed_response({"response_body": data})
+    return completed_response_with_logs(logs, {"response_body": data})
+
+
+@logging_handler(log)
+def read_x_tenant(task, logs):
+    """
+    Read X_TENANT_ID variable and return as a string.
+    Fail if X_TENANT_ID is not found.
+    """
+
+    if "X_TENANT_ID" not in os.environ:
+        return failed_response_with_logs(logs, "X_TENANT_ID not found in the environment")
+    return completed_response_with_logs(logs, {"X_TENANT_ID": os.environ["X_TENANT_ID"]})
+
+
+@logging_handler(log)
+def read_resource_manager_url_base(task, logs):
+    """
+    Read resource_manager_base variable and return as a string.
+    """
+
+    return completed_response_with_logs(
+        logs, {"RESOURCE_MANAGER_URL_BASE": resource_manager_url_base}
+    )
+
+
+@logging_handler(log)
+def accumulate_report(task, logs):
+    """
+    Accumulate one report from two reports
+
+         Args:
+
+             task (dict): dictionary with input data ["first_report", "last_report"]
+
+             logs: stream of log messages
+
+        Returns:
+            Accumulated subnets from 2 input reports:
+            "response_body":{"/24":"2","/25":"4","/26":"8","/27":"16","/28":"32","/29":"64","/30":"128","/31":"256","/32":"512"}
+    """
+    first_report = dict(task["inputData"]["first_report"])
+    last_report = dict(task["inputData"]["last_report"])
+    global_report = dict()
+
+    if first_report:
+        if len(first_report) < len(last_report):
+            for key, value in last_report.items():
+                if key not in first_report.keys():
+                    global_report[key] = int(value)
+                elif key in first_report.keys():
+                    values = int(value) + int(first_report[key])
+                    global_report.update({key: str(values)})
+        else:
+            for key, value in first_report.items():
+                if key not in last_report.keys():
+                    global_report[key] = int(value)
+                elif key in last_report.keys():
+                    values = int(value) + int(last_report[key])
+                    global_report.update({key: str(values)})
+    else:
+        global_report = last_report
+    return completed_response_with_logs(logs, {"response_body": global_report})
+
+
+@logging_handler(log)
+def calculate_available_prefixes_for_address_pool(task, logs):
+    """
+    Calculate available prefixes for address pool
+
+         Args:
+
+             task (dict): dictionary with input data ["free_capacity", "resource_type"]
+
+             logs: stream of log messages
+        Returns:
+            "result":{"/24":"1","/25":"2","/26":"4","/27":"8","/28":"16","/29":"32","/30":"64","/31":"128","/32":"256"}
+    """
+    free_capacity = task["inputData"]["free_capacity"]
+    resource_type = str(task["inputData"]["resource_type"])
+
+    available_prefixes = {}
+
+    if resource_type.startswith("ipv4"):
+        for prefix in range(1, 33):
+            prefix_capacity = 2 ** (32 - prefix)
+            if prefix_capacity <= int(free_capacity):
+                result = int(free_capacity) // prefix_capacity
+                available_prefixes["/" + str(prefix)] = str(result)
+    elif resource_type.startswith("ipv6"):
+        for prefix in range(1, 129):
+            prefix_capacity = 2 ** (128 - prefix)
+            if prefix_capacity <= int(free_capacity):
+                result = int(free_capacity) // prefix_capacity
+                available_prefixes["/" + str(prefix)] = str(result)
+
+    return completed_response_with_logs(logs, {"result": available_prefixes})
 
 
 def start(cc):
@@ -834,7 +920,6 @@ def start(cc):
         query_pool_by_tag,
     )
 
-
     cc.register(
         "RESOURCE_MANAGER_query_vlan_range_pool",
         {
@@ -849,3 +934,78 @@ def start(cc):
         },
         query_vlan_range_pool,
     )
+
+    cc.register(
+        "Read_x_tenant",
+        {
+            "name": "Read_x_tenant",
+            "description": '{"description": "Input format: X_TENANT_ID"}',
+            "retryCount": 0,
+            "timeoutPolicy": "TIME_OUT_WF",
+            "retryLogic": "FIXED",
+            "retryDelaySeconds": 0,
+            "inputKeys": [],
+            "outputKeys": [],
+        },
+        read_x_tenant,
+    )
+
+    cc.register(
+        "Read_resource_manager_url_base",
+        {
+            "name": "Read_resource_manager_url_base",
+            "description": '{"description": "Input format: RESOURCE_MANAGER_URL_BASE"}',
+            "retryCount": 0,
+            "timeoutPolicy": "TIME_OUT_WF",
+            "retryLogic": "FIXED",
+            "retryDelaySeconds": 0,
+            "inputKeys": [],
+            "outputKeys": [],
+        },
+        read_resource_manager_url_base,
+    )
+
+    cc.register(
+        "RESOURCE_MANAGER_accumulate_report",
+        {
+            "name": "RESOURCE_MANAGER_accumulate_report",
+            "description": '{"description": "": [""]}',
+            "retryCount": 0,
+            "timeoutPolicy": "TIME_OUT_WF",
+            "retryLogic": "FIXED",
+            "retryDelaySeconds": 0,
+            "inputKeys": [""],
+            "outputKeys": [],
+        },
+        accumulate_report,
+    )
+
+    cc.register(
+        "RESOURCE_MANAGER_calculate_available_prefixes_for_address_pool",
+        {
+            "name": "RESOURCE_MANAGER_calculate_available_prefixes_for_address_pool",
+            "description": '{"description": "": [""]}',
+            "retryCount": 0,
+            "timeoutPolicy": "TIME_OUT_WF",
+            "retryLogic": "FIXED",
+            "retryDelaySeconds": 0,
+            "inputKeys": [""],
+            "outputKeys": [],
+        },
+        calculate_available_prefixes_for_address_pool,
+    )
+
+    cc.register(
+        "RESOURCE_MANAGER_update_alt_id_for_resource",
+        {
+            "name": "RESOURCE_MANAGER_update_alt_id_for_resource",
+            "description": '{"description": "": [""]}',
+            "retryCount": 0,
+            "timeoutPolicy": "TIME_OUT_WF",
+            "retryLogic": "FIXED",
+            "retryDelaySeconds": 0,
+            "inputKeys": [""],
+            "outputKeys": [],
+        },
+        update_alt_id_for_resource,
+    )
